from setuptools import setup, find_packages

setup(
    name='our1314',
    version='0.1.21',
    keywords='our1314',
    description='a library for work',
    license='MIT License',
    url='https://github.com/our1314/our1314-python',
    author='pp',
    author_email='our1314@foxmail.com',
    packages=find_packages(),
    include_package_data=True,
    platforms='any',
    install_requires=[],
)
